@@ -14,7 +14,7 @@
  * libxml++ is a C++ wrapper for the <a href="http://xmlsoft.org/">libxml2</a> XML parser and builder library. It presents a
  * simple C++-like API that can achieve common tasks with less code.
  *
- * See also the <a href="https://developer-old.gnome.org/libxml++-tutorial/4.0/">libxml++ Tutorial</a>
+ * See also the <a href="https://developer.gnome.org/libxml++-tutorial/stable/">libxml++ Tutorial</a>
  * and the <a href="https://libxmlplusplus.github.io/libxmlplusplus/">libxml++ website</a>.
  *
  * @section features Features
@@ -34,14 +34,14 @@
  *
  * If your source file is @c program.cc, you can compile it with:
  * @code
- * g++ program.cc -o program `pkg-config --cflags --libs libxml++-4.0`
+ * g++ program.cc -o program `pkg-config --cflags --libs libxml++-5.0`
  * @endcode
  * If your version of g++ is not C++17-compliant be default,
  * add the @c -std=c++17 option.
  *
  * Alternatively, if using autoconf, use the following in @c configure.ac:
  * @code
- * PKG_CHECK_MODULES([LIBXMLXX], [libxml++-4.0])
+ * PKG_CHECK_MODULES([LIBXMLXX], [libxml++-5.0])
  * @endcode
  * Then use the generated @c LIBXMLXX_CFLAGS and @c LIBXMLXX_LIBS variables in
  * the project @c Makefile.am files. For example:
@@ -75,5 +75,6 @@
 #include <libxml++/validators/dtdvalidator.h>
 #include <libxml++/validators/relaxngvalidator.h>
 #include <libxml++/validators/xsdvalidator.h>
+#include <libxml++/ustring.h>
 
 #endif //__LIBXMLCPP_H
